@@ -15,9 +15,8 @@ class WindowSettings : public QWidget, private Ui::WindowSettings
 
 public:
     explicit WindowSettings(QWidget *parent = nullptr);
-    ~WindowSettings();
+    ~WindowSettings() override;
 
-private:
 Q_SIGNALS:
     void updateWindowGeometry(int width, int height, int position);
 
